==> pierogi_1.1.45.tar.gz: pierogi-1.1.45/keysets/bose.h <==
//
// bose.h
//
// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef BOSE_H
#define BOSE_H

#include "pirkeysetmetadata.h"

class QComboBox;

class BoseRadio1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  BoseRadio1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class BoseRadio2: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  BoseRadio2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class BoseRadio3: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  BoseRadio3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class BoseHomeTheater1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  BoseHomeTheater1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

#endif // BOSE_H

==> pierogi_1.1.48.tar.gz: pierogi-1.1.48/keysets/bose.h <==
//
// bose.h
//
// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef BOSE_H
#define BOSE_H

#include "pirkeysetmetadata.h"

class QComboBox;

class BoseRadio1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  BoseRadio1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb) const;
};

class BoseRadio2: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  BoseRadio2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb) const;
};

class BoseRadio3: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  BoseRadio3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb) const;
};

class BoseHomeTheater1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  BoseHomeTheater1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb) const;
};

#endif // BOSE_H
